require(Hmisc)
require(lme4)
require(psych)
require(ggplot2)
require(eyetrackingR)
require(Matrix)

ip <- as.data.frame(installed.packages()[,c(1,3:4)])#tells you what packages you're using for paper
rownames(ip) <- NULL
ip <- ip[is.na(ip$Priority),1:2,drop=FALSE]
print(ip, row.names=FALSE)

R.Version()
citation()

#load data, tidy up, code conditions####

#read in tab separated data files from Tobii studio. change to read.csv if you have comma separated files or read.xlsx if you've got excel files.  change value of sep to tell it what the separator is. data with filenames beginning "dFM" are data from dropped children. Reasons for drop are explained in FMCOL-summary.xlsx.
data1=read.table("FMVC1M1.tsv", sep="\t", head=TRUE)
data2=read.table("FMVC1M2.tsv", sep="\t", head=TRUE)
data3=read.table("FMVC2F4.tsv", sep="\t", head=TRUE)
data4=read.table("FMVC2M2.tsv", sep="\t", head=TRUE)
data5=read.table("FMVC3F1.tsv", sep="\t", head=TRUE)
data6=read.table("FMVC3M2.tsv", sep="\t", head=TRUE)
data7=read.table("FMVC3M3.tsv", sep="\t", head=TRUE)
data8=read.table("FMVC4F3.tsv", sep="\t", head=TRUE)
data9=read.table("FMVC4M1.tsv", sep="\t", head=TRUE)
data10=read.table("FMVC4M4.tsv", sep="\t", head=TRUE)
data11=read.table("FMVC5F1.tsv", sep="\t", head=TRUE)
data12=read.table("FMVC5F2.tsv", sep="\t", head=TRUE)
data13=read.table("FMVC5M3.tsv", sep="\t", head=TRUE)
data14=read.table("FMVC6F2.tsv", sep="\t", head=TRUE)
data15=read.table("FMVC6F3.tsv", sep="\t", head=TRUE)
data16=read.table("FMVC6M1.tsv", sep="\t", head=TRUE)
data17=read.table("FMCC1F3.tsv", sep="\t", head=TRUE)
data18=read.table("FMCC1M2.tsv", sep="\t", head=TRUE)
data19=read.table("FMCC2F3.tsv", sep="\t", head=TRUE)
data20=read.table("FMCC2M1.tsv", sep="\t", head=TRUE)
data21=read.table("FMCC2M2.tsv", sep="\t", head=TRUE)
data22=read.table("FMCC3M1.tsv", sep="\t", head=TRUE)
data23=read.table("FMCC3M2.tsv", sep="\t", head=TRUE)
data24=read.table("FMCC3M3.tsv", sep="\t", head=TRUE)
data25=read.table("FMCC4F2.tsv", sep="\t", head=TRUE)
data26=read.table("FMCC4F3.tsv", sep="\t", head=TRUE)
data27=read.table("FMCC5F1.tsv", sep="\t", head=TRUE)
data28=read.table("FMCC5F2.tsv", sep="\t", head=TRUE)
data29=read.table("FMCC6F1.tsv", sep="\t", head=TRUE)
data30=read.table("FMCC6M2.tsv", sep="\t", head=TRUE)

#bind all the files together into one big dataframe
data=rbind(data1,data2)
data=rbind(data,data3)
data=rbind(data,data4)
data=rbind(data,data5)
data=rbind(data,data6)
data=rbind(data,data7)
data=rbind(data,data8)
data=rbind(data,data9)
data=rbind(data,data10)
data=rbind(data,data11)
data=rbind(data,data12)
data=rbind(data,data13)
data=rbind(data,data14)
data=rbind(data,data15)
data=rbind(data,data16)
data=rbind(data,data17)
data=rbind(data,data18)
data=rbind(data,data19)
data=rbind(data,data20)
data=rbind(data,data21)
data=rbind(data,data22)
data=rbind(data,data23)
data=rbind(data,data24)
data=rbind(data,data25)
data=rbind(data,data26)
data=rbind(data,data27)
data=rbind(data,data28)
data=rbind(data,data29)
data=rbind(data,data30)

#check what types of video we have
xtabs(~MediaName, data)
#
#we're only interested in RS and Ret trials ("after break and "after break" and "before break") so exclude anything else. Note: "after break" and "before break" videos include attention getter trials. These are coded and excluded later
#
data=subset(data, MediaName %nin% c("AG4.avi","AG6.avi","attention getter.wmv","blank.wmv","shaun the sheep.wmv", ""))

head(data)
data$X=NULL#get rid of unnecessary column
data$validsum=data$ValidityLeft+data$ValidityRight#make a new column that adds the two validity columns. These show 4 if the left or right eye is not detected, so values of 8 indicate that the eyetracker didn't reliably detect either eye. Use this later to clean the data

#make friendly column names
colnames(data) = c("pnum", "recname", "media","timestamp","gazex","gazey", "valleft", "valright", "validsum")

head(data)#check it looks ok
xtabs(~pnum, data)#check each participant has values
xtabs(~media, data)#check only "before break" and "after break" videos have values

#code referent selection/retention trials. note inconsistent spacing is deliberate
data$phase=ifelse(data$media %in% c("after break1.wmv", "after break 2.wmv", "after break3.wmv", "after break 4.wmv", "after break 5.wmv","after break6.wmv"), "Ret", "RS")
xtabs(~phase + pnum, data)#should be more trials for RS than ret.

vc4m1=subset(data, recname == "FMVC4M1")
tail(vc4m1)#no retention data for this child
#
#code condition and order
data$cond=NA
data$order=NA
#
data$cond[grep("VC",data$pnum)]="VC"#for each row of the dataset, searches for "VC" in data$pnum, and if it finds it, puts "VC" in data$cond
data$cond[grep("CC",data$pnum)]="CC"
data$order[grep("CC1",data$pnum)]="CC1"
data$order[grep("CC2",data$pnum)]="CC2"
data$order[grep("CC3",data$pnum)]="CC3"
data$order[grep("CC4",data$pnum)]="CC4"
data$order[grep("CC5",data$pnum)]="CC5"
data$order[grep("CC6",data$pnum)]="CC6"
data$order[grep("VC1",data$pnum)]="VC1"
data$order[grep("VC2",data$pnum)]="VC2"
data$order[grep("VC3",data$pnum)]="VC3"
data$order[grep("VC4",data$pnum)]="VC4"
data$order[grep("VC5",data$pnum)]="VC5"
data$order[grep("VC6",data$pnum)]="VC6"

head(data)#check there are entries indata$cond and data$order, not NAs

xtabs(~order, data)#check there are values for each order.
xtabs(~pnum + cond, data)#check each participant only has values in one condition


#add summary data to main data file, make timings relative to start of presentation of first ret trial#####

data_summary=read.csv("fmcol-summary-anon.csv")#load summary data; vocab level, info about how studies ran etc. Note this sheet has been anonymised for sharing: ages and dates of birth have been removed. t-tests on age will therefore not reflect the actual statistics reported in the paper.
head(data_summary)
#
data_summary$cond=NULL#get rid of column to stop it duplicating when we merge our data with our summary
data_summary$order=NULL

describe(data_summary)#descriptives
#t.test(data_summary$agemonths ~ data_summary$cond, alternative="two.sided", paired = FALSE)#won't run on anonymized data
#t.test(data_summary$vocabprod ~ data_summary$cond, alternative="two.sided", paired = FALSE)#won't run on anonymized data

data2=merge(data, data_summary, by=c("pnum"))
head(data2)
data=data2
head(data)
data$recname = NULL

head(data)

#the raw data don't start from the beginning of recording (i.e. timestamp 0) because there were AGs etc preceding it which we have discarded. But, to assign trial names, label timings etc. we need to make sure we have a zero point for the beginning of RS. Everything will be jittered slightly. For example, the no. timestamps prior to presentation of the first RS stimulus varies; also something about the conversion process from Powerpoint to .avi seems to mess up the timings slightly

#this code makes a dataframe with one column for participant number and another containing the timestamp at which the first RS trial was presented

startdata=data.frame(1,2)#make a data frame with 1 row and two columns

startdata[1,1]="FMVC6M1"#put a participant number in the first row first column of startdata
startdata[1,2]=(subset(data, pnum == "FMVC6M1"))[1,3]#put the value of the first timestamp in the second column of startdata. CHECK third column of data is $timestamp, if not, change
startdata[2,1]="FMVC6F3"
startdata[2,2]=(subset(data, pnum == "FMVC6F3"))[1,3]
startdata[3,1]="FMVC6F2"
startdata[3,2]=(subset(data, pnum == "FMVC6F2"))[1,3]
startdata[4,1]="FMVC5M3"
startdata[4,2]=(subset(data, pnum == "FMVC5M3"))[1,3]
startdata[5,1]="FMVC5F2"
startdata[5,2]=(subset(data, pnum == "FMVC5F2"))[1,3]
startdata[6,1]="FMVC5F1"
startdata[6,2]=(subset(data, pnum == "FMVC5F1"))[1,3]
startdata[7,1]="FMVC4M4"
startdata[7,2]=(subset(data, pnum == "FMVC4M4"))[1,3]
startdata[8,1]="FMVC4M1"
startdata[8,2]=(subset(data, pnum == "FMVC4M1"))[1,3]
startdata[9,1]="FMVC4F3"
startdata[9,2]=(subset(data, pnum == "FMVC4F3"))[1,3]
startdata[10,1]="FMVC3M3"
startdata[10,2]=(subset(data, pnum == "FMVC3M3"))[1,3]
startdata[11,1]="FMVC3M2"
startdata[11,2]=(subset(data, pnum == "FMVC3M2"))[1,3]
startdata[12,1]="FMVC3F1"
startdata[12,2]=(subset(data, pnum == "FMVC3F1"))[1,3]
startdata[13,1]="FMVC2M2"
startdata[13,2]=(subset(data, pnum == "FMVC2M2"))[1,3]
startdata[14,1]="FMVC2F4"
startdata[14,2]=(subset(data, pnum == "FMVC2F4"))[1,3]
startdata[15,1]="FMVC1M2"
startdata[15,2]=(subset(data, pnum == "FMVC1M2"))[1,3]
startdata[16,1]="FMVC1M1"
startdata[16,2]=(subset(data, pnum == "FMVC1M1"))[1,3]
startdata[17,1]="FMCC6M2"
startdata[17,2]=(subset(data, pnum == "FMCC6M2"))[1,3]
startdata[18,1]="FMCC6F1"
startdata[18,2]=(subset(data, pnum == "FMCC6F1"))[1,3]
startdata[19,1]="FMCC5F2"
startdata[19,2]=(subset(data, pnum == "FMCC5F2"))[1,3]
startdata[20,1]="FMCC5F1"
startdata[20,2]=(subset(data, pnum == "FMCC5F1"))[1,3]
startdata[21,1]="FMCC4F3"
startdata[21,2]=(subset(data, pnum == "FMCC4F3"))[1,3]
startdata[22,1]="FMCC4F2"
startdata[22,2]=(subset(data, pnum == "FMCC4F2"))[1,3]
startdata[23,1]="FMCC3M3"
startdata[23,2]=(subset(data, pnum == "FMCC3M3"))[1,3]
startdata[24,1]="FMCC3M2"
startdata[24,2]=(subset(data, pnum == "FMCC3M2"))[1,3]
startdata[25,1]="FMCC3M1"
startdata[25,2]=(subset(data, pnum == "FMCC3M1"))[1,3]
startdata[26,1]="FMCC2M2"
startdata[26,2]=(subset(data, pnum == "FMCC2M2"))[1,3]
startdata[27,1]="FMCC2M1"
startdata[27,2]=(subset(data, pnum == "FMCC2M1"))[1,3]
startdata[28,1]="FMCC2F3"
startdata[28,2]=(subset(data, pnum == "FMCC2F3"))[1,3]
startdata[29,1]="FMCC1M2"
startdata[29,2]=(subset(data, pnum == "FMCC1M2"))[1,3]
startdata[30,1]="FMCC1F3"
startdata[30,2]=(subset(data, pnum == "FMCC1F3"))[1,3]
#
colnames(startdata) = c("pnum","firsttrialonset")
head(startdata)#check it looks ok

xtabs(~pnum, startdata)#check there's one row per participant
#
data=merge(data, startdata, by="pnum")#join the summary and the data together by pnum
head(data)#check summary columns have been added to data
data$timefromfirsttrialonset=(data$timestamp-data$firsttrialonset)+1#make a column of timestamps relative to onset of firs trial
data$X = NULL#get rid of any X columns (these get added if you open your data in Excel)
head(data)
xtabs(~pnum, data)#final check that all participants have data
write.csv(data, "fmcol-data-1.csv")#SAVE data so you don't have to do all that again!

#code individual trial types based on original counterbalancing#####

#new we need to tell it what trial is happening at what timestamp (equivalent to using sections in Tobii Studio).
# need to code ret and RS separately as we don't know whether there were differences in break lengths.
# use fmcol-cbal.csv for timings for trials (I made this manually by slowing down videos and working out trial durations/orders)
#note (e.g.) order 1 VC1 and CC1 are the same except for background so we can code all order 1 data together, all order 2 data together, etc

#data = read.csv("fmcol-data-1.csv")
xtabs(~pnum, data)

#order 1####
rsdataord1 =subset(data, order %in% c("CC1", "VC1") & phase == "RS")
retdataord1 =subset(data, order %in% c("CC1", "VC1") & phase == "Ret")

rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset <= 7000 ] = "aghirs"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >7000 & rsdataord1$timefromfirsttrialonset <=23000 ] = "train1"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >23000 & rsdataord1$timefromfirsttrialonset <=39000 ] = "train2"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >39000 & rsdataord1$timefromfirsttrialonset <=55000 ] = "train3"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >55000 & rsdataord1$timefromfirsttrialonset <=68000 ] = "RS1"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >68000 & rsdataord1$timefromfirsttrialonset <=71000 ] = "AG1"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >71000 & rsdataord1$timefromfirsttrialonset <=84000 ] = "RS2"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >84000 & rsdataord1$timefromfirsttrialonset <=970000 ] = "RS3"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >97000 & rsdataord1$timefromfirsttrialonset <=110000 ] = "RS4"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >110000 & rsdataord1$timefromfirsttrialonset <=113000 ] = "AG2"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >113000 & rsdataord1$timefromfirsttrialonset <=126000 ] = "RS5"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >126000 & rsdataord1$timefromfirsttrialonset <=139000 ] = "RS6"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >139000 & rsdataord1$timefromfirsttrialonset <=152000 ] = "RS7"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >152000 & rsdataord1$timefromfirsttrialonset <=155000 ] = "AG3"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >155000 & rsdataord1$timefromfirsttrialonset <=168000 ] = "RS8"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >168000 & rsdataord1$timefromfirsttrialonset <=181000 ] = "RS9"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >181000 & rsdataord1$timefromfirsttrialonset <=184000 ] = "AG4"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >184000 & rsdataord1$timefromfirsttrialonset <=197000 ] = "RS10"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >197000 & rsdataord1$timefromfirsttrialonset <=210000 ] = "RS11"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >210000 & rsdataord1$timefromfirsttrialonset <=213000 ] = "AG5"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >213000 & rsdataord1$timefromfirsttrialonset <=226000 ] = "RS12"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >226000 & rsdataord1$timefromfirsttrialonset <=239000 ] = "RS13"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >239000 & rsdataord1$timefromfirsttrialonset <=252000 ] = "RS14"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >252000 & rsdataord1$timefromfirsttrialonset <=255000 ] = "AG6"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >255000 & rsdataord1$timefromfirsttrialonset <=268000 ] = "RS15"
rsdataord1$trialtype[rsdataord1$timefromfirsttrialonset >268000 & rsdataord1$timefromfirsttrialonset <=272000 ] = "agwelldone"

#ret will be the same for all orders (but remember to change the onset time)
retdataord1$timefromfirsttrialonset=retdataord1$timefromfirsttrialonset - retdataord1$timefromfirsttrialonset[1] +1#get timestamp for start of test value manually
retdataord1$trialtype[retdataord1$timefromfirsttrialonset <= 7000 ] = "aghiret"
retdataord1$trialtype[retdataord1$timefromfirsttrialonset > 7000 & retdataord1$timefromfirsttrialonset <= 19500] = "reeng"
retdataord1$trialtype[retdataord1$timefromfirsttrialonset > 19500 & retdataord1$timefromfirsttrialonset <= 32000] = "ret1"
retdataord1$trialtype[retdataord1$timefromfirsttrialonset > 32000 & retdataord1$timefromfirsttrialonset <= 44500] = "ret2"
retdataord1$trialtype[retdataord1$timefromfirsttrialonset > 44500 & retdataord1$timefromfirsttrialonset <= 57000] = "ret3"
retdataord1$trialtype[retdataord1$timefromfirsttrialonset > 57000 & retdataord1$timefromfirsttrialonset <= 69500] = "ret4"
retdataord1$trialtype[retdataord1$timefromfirsttrialonset > 69500 & retdataord1$timefromfirsttrialonset <= 82000] = "ret5"
retdataord1$trialtype[retdataord1$timefromfirsttrialonset > 82000 & retdataord1$timefromfirsttrialonset <= 94500] = "ret6"

dataord1=rbind(rsdataord1, retdataord1)

#order 2####
rsdataord2 =subset(data, order %in% c("CC2", "VC2") & phase == "RS")
retdataord2 =subset(data, order %in% c("CC2", "VC2") & phase == "Ret")
#
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset <= 7000 ] = "aghirs"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >7000 & rsdataord2$timefromfirsttrialonset <=23000 ] = "train1"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >23000 & rsdataord2$timefromfirsttrialonset <=39000 ] = "train2"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >39000 & rsdataord2$timefromfirsttrialonset <=55000 ] = "train3"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >55000 & rsdataord2$timefromfirsttrialonset <=58000 ] = "AG1"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >58000 & rsdataord2$timefromfirsttrialonset <=71000 ] = "RS1"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >71000 & rsdataord2$timefromfirsttrialonset <=84000 ] = "RS2"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >84000 & rsdataord2$timefromfirsttrialonset <=97000 ] = "RS3"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >97000 & rsdataord2$timefromfirsttrialonset <=100000 ] = "AG2"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >100000 & rsdataord2$timefromfirsttrialonset <=113000 ] = "RS4"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >113000 & rsdataord2$timefromfirsttrialonset <=126000 ] = "RS5"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >126000 & rsdataord2$timefromfirsttrialonset <=129000 ] = "AG3"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >129000 & rsdataord2$timefromfirsttrialonset <=142000 ] = "RS6"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >142000 & rsdataord2$timefromfirsttrialonset <=155000 ] = "RS7"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >155000 & rsdataord2$timefromfirsttrialonset <=168000 ] = "RS8"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >168000 & rsdataord2$timefromfirsttrialonset <=171000 ] = "AG4"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >171000 & rsdataord2$timefromfirsttrialonset <=184000 ] = "RS9"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >184000 & rsdataord2$timefromfirsttrialonset <=197000 ] = "RS10"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >197000 & rsdataord2$timefromfirsttrialonset <=200000 ] = "AG5"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >200000 & rsdataord2$timefromfirsttrialonset <=213000 ] = "RS11"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >213000 & rsdataord2$timefromfirsttrialonset <=226000 ] = "RS12"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >226000 & rsdataord2$timefromfirsttrialonset <=239000 ] = "RS13"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >239000 & rsdataord2$timefromfirsttrialonset <=242000 ] = "AG6"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >242000 & rsdataord2$timefromfirsttrialonset <=255000 ] = "RS14"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >255000 & rsdataord2$timefromfirsttrialonset <=268000 ] = "RS15"
rsdataord2$trialtype[rsdataord2$timefromfirsttrialonset >268000 & rsdataord2$timefromfirsttrialonset <=272000 ] = "agwelldone"

retdataord2$timefromfirsttrialonset=retdataord2$timefromfirsttrialonset - retdataord2$timefromfirsttrialonset[1] +1#get timestamp for start of test value manually
head(retdataord2)
retdataord2$trialtype[retdataord2$timefromfirsttrialonset <= 7000 ] = "aghiret"
retdataord2$trialtype[retdataord2$timefromfirsttrialonset > 7000 & retdataord2$timefromfirsttrialonset <= 19500] = "reeng"
retdataord2$trialtype[retdataord2$timefromfirsttrialonset > 19500 & retdataord2$timefromfirsttrialonset <= 32000] = "ret1"
retdataord2$trialtype[retdataord2$timefromfirsttrialonset > 32000 & retdataord2$timefromfirsttrialonset <= 44500] = "ret2"
retdataord2$trialtype[retdataord2$timefromfirsttrialonset > 44500 & retdataord2$timefromfirsttrialonset <= 57000] = "ret3"
retdataord2$trialtype[retdataord2$timefromfirsttrialonset > 57000 & retdataord2$timefromfirsttrialonset <= 69500] = "ret4"
retdataord2$trialtype[retdataord2$timefromfirsttrialonset > 69500 & retdataord2$timefromfirsttrialonset <= 82000] = "ret5"
retdataord2$trialtype[retdataord2$timefromfirsttrialonset > 82000 & retdataord2$timefromfirsttrialonset <= 94500] = "ret6"

head(rsdataord2)
head(retdataord2)

dataord2=rbind(rsdataord2, retdataord2)
#
#order 3####
rsdataord3 =subset(data, order %in% c("CC3", "VC3") & phase == "RS")
retdataord3 =subset(data, order %in% c("CC3", "VC3") & phase == "Ret")

rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset <= 7000 ] = "aghirs"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >7000 & rsdataord3$timefromfirsttrialonset <=23000 ] = "train1"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >23000 & rsdataord3$timefromfirsttrialonset <=39000 ] = "train2"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >39000 & rsdataord3$timefromfirsttrialonset <=55000 ] = "train3"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >55000 & rsdataord3$timefromfirsttrialonset <=68000 ] = "RS1"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >68000 & rsdataord3$timefromfirsttrialonset <=81000 ] = "RS2"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >81000 & rsdataord3$timefromfirsttrialonset <=84000 ] = "AG1"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >84000 & rsdataord3$timefromfirsttrialonset <=97000 ] = "RS3"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >97000 & rsdataord3$timefromfirsttrialonset <=110000 ] = "RS4"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >110000 & rsdataord3$timefromfirsttrialonset <=113000 ] = "AG2"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >113000 & rsdataord3$timefromfirsttrialonset <=126000 ] = "RS5"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >126000 & rsdataord3$timefromfirsttrialonset <=139000 ] = "RS6"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >139000 & rsdataord3$timefromfirsttrialonset <=152000 ] = "RS7"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >152000 & rsdataord3$timefromfirsttrialonset <=155000 ] = "AG3"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >155000 & rsdataord3$timefromfirsttrialonset <=168000 ] = "RS8"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >169000 & rsdataord3$timefromfirsttrialonset <=181000 ] = "RS9"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >181000 & rsdataord3$timefromfirsttrialonset <=184000 ] = "AG4"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >184000 & rsdataord3$timefromfirsttrialonset <=197000 ] = "RS10"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >197000 & rsdataord3$timefromfirsttrialonset <=210000 ] = "RS11"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >210000 & rsdataord3$timefromfirsttrialonset <=223000 ] = "RS12"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >223000 & rsdataord3$timefromfirsttrialonset <=226000 ] = "AG5"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >226000 & rsdataord3$timefromfirsttrialonset <=239000 ] = "RS13"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >239000 & rsdataord3$timefromfirsttrialonset <=252000 ] = "RS14"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >252000 & rsdataord3$timefromfirsttrialonset <=255000 ] = "AG6"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >255000 & rsdataord3$timefromfirsttrialonset <=268000 ] = "RS15"
rsdataord3$trialtype[rsdataord3$timefromfirsttrialonset >268000 & rsdataord3$timefromfirsttrialonset <=272000 ] = "agwelldone"
#
#this will be the same for all orders (but remember to change the timestamp to first value in $timefromfirsttrialonset)
retdataord3$timefromfirsttrialonset=retdataord3$timefromfirsttrialonset - retdataord3$timefromfirsttrialonset[1] +1#get timestamp for start of test value manually
head(retdataord3)
retdataord3$trialtype[retdataord3$timefromfirsttrialonset <= 7000 ] = "aghiret"
retdataord3$trialtype[retdataord3$timefromfirsttrialonset > 7000 & retdataord3$timefromfirsttrialonset <= 19500] = "reeng"
retdataord3$trialtype[retdataord3$timefromfirsttrialonset > 19500 & retdataord3$timefromfirsttrialonset <= 32000] = "ret1"
retdataord3$trialtype[retdataord3$timefromfirsttrialonset > 32000 & retdataord3$timefromfirsttrialonset <= 44500] = "ret2"
retdataord3$trialtype[retdataord3$timefromfirsttrialonset > 44500 & retdataord3$timefromfirsttrialonset <= 57000] = "ret3"
retdataord3$trialtype[retdataord3$timefromfirsttrialonset > 57000 & retdataord3$timefromfirsttrialonset <= 69500] = "ret4"
retdataord3$trialtype[retdataord3$timefromfirsttrialonset > 69500 & retdataord3$timefromfirsttrialonset <= 82000] = "ret5"
retdataord3$trialtype[retdataord3$timefromfirsttrialonset > 82000 & retdataord3$timefromfirsttrialonset <= 94500] = "ret6"

dataord3=rbind(rsdataord3, retdataord3)

#order 4####
rsdataord4 =subset(data, order %in% c("CC4", "VC4") & phase == "RS")
retdataord4 =subset(data, order %in% c("CC4", "VC4") & phase == "Ret")
#
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset <= 7000 ] = "aghirs"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >7000 & rsdataord4$timefromfirsttrialonset <=23000 ] = "train1"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >23000 & rsdataord4$timefromfirsttrialonset <=39000 ] = "train2"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >39000 & rsdataord4$timefromfirsttrialonset <=55000 ] = "train3"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >55000 & rsdataord4$timefromfirsttrialonset <=68000 ] = "RS1"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >68000 & rsdataord4$timefromfirsttrialonset <=71000 ] = "AG1"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >71000 & rsdataord4$timefromfirsttrialonset <=84000 ] = "RS2"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >84000 & rsdataord4$timefromfirsttrialonset <=97000 ] = "RS3"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >97000 & rsdataord4$timefromfirsttrialonset <=110000 ] = "RS4"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >110000 & rsdataord4$timefromfirsttrialonset <=113000 ] = "AG2"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >113000 & rsdataord4$timefromfirsttrialonset <=126000 ] = "RS5"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >126000 & rsdataord4$timefromfirsttrialonset <=139000 ] = "RS6"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >139000 & rsdataord4$timefromfirsttrialonset <=142000 ] = "AG3"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >142000 & rsdataord4$timefromfirsttrialonset <=155000 ] = "RS7"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >155000 & rsdataord4$timefromfirsttrialonset <=168000 ] = "RS8"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >168000 & rsdataord4$timefromfirsttrialonset <=181000 ] = "RS9"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >181000 & rsdataord4$timefromfirsttrialonset <=184000 ] = "AG4"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >184000 & rsdataord4$timefromfirsttrialonset <=197000 ] = "RS10"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >197000 & rsdataord4$timefromfirsttrialonset <=210000] = "RS11"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >210000 & rsdataord4$timefromfirsttrialonset <=213000 ] = "AG5"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >213000 & rsdataord4$timefromfirsttrialonset <=226000 ] = "RS12"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >226000 & rsdataord4$timefromfirsttrialonset <=239000 ] = "RS13"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >239000 & rsdataord4$timefromfirsttrialonset <=242000 ] = "AG6"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >242000 & rsdataord4$timefromfirsttrialonset <=255000 ] = "RS14"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >255000 & rsdataord4$timefromfirsttrialonset <=268000 ] = "RS15"
rsdataord4$trialtype[rsdataord4$timefromfirsttrialonset >268000 & rsdataord4$timefromfirsttrialonset <=272000 ] = "agwelldone"

#this will be the same for all orders (but remember to change the timestamp to first value in $timefromfirsttrialonset)
retdataord4$timefromfirsttrialonset=retdataord4$timefromfirsttrialonset - retdataord4$timefromfirsttrialonset[1] +1#get timestamp for start of test value manually
head(retdataord4)

retdataord4$trialtype[retdataord4$timefromfirsttrialonset <= 7000 ] = "aghiret"
retdataord4$trialtype[retdataord4$timefromfirsttrialonset > 7000 & retdataord4$timefromfirsttrialonset <= 19500] = "reeng"
retdataord4$trialtype[retdataord4$timefromfirsttrialonset > 19500 & retdataord4$timefromfirsttrialonset <= 32000] = "ret1"
retdataord4$trialtype[retdataord4$timefromfirsttrialonset > 32000 & retdataord4$timefromfirsttrialonset <= 44500] = "ret2"
retdataord4$trialtype[retdataord4$timefromfirsttrialonset > 44500 & retdataord4$timefromfirsttrialonset <= 57000] = "ret3"
retdataord4$trialtype[retdataord4$timefromfirsttrialonset > 57000 & retdataord4$timefromfirsttrialonset <= 69500] = "ret4"
retdataord4$trialtype[retdataord4$timefromfirsttrialonset > 69500 & retdataord4$timefromfirsttrialonset <= 82000] = "ret5"
retdataord4$trialtype[retdataord4$timefromfirsttrialonset > 82000 & retdataord4$timefromfirsttrialonset <= 94500] = "ret6"

dataord4=rbind(rsdataord4, retdataord4)

#order 5####
rsdataord5 =subset(data, order %in% c("CC5", "VC5") & phase == "RS")
retdataord5 =subset(data, order %in% c("CC5", "VC5") & phase == "Ret")

rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset <= 7000 ] = "aghirs"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >7000 & rsdataord5$timefromfirsttrialonset <=23000 ] = "train1"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >23000 & rsdataord5$timefromfirsttrialonset <=39000 ] = "train2"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >39000 & rsdataord5$timefromfirsttrialonset <=55000 ] = "train3"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >55000 & rsdataord5$timefromfirsttrialonset <=68000 ] = "RS1"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >68000 & rsdataord5$timefromfirsttrialonset <=81000 ] = "RS2"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >81000 & rsdataord5$timefromfirsttrialonset <=84000 ] = "AG1"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >84000 & rsdataord5$timefromfirsttrialonset <=97000 ] = "RS3"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >97000 & rsdataord5$timefromfirsttrialonset <=110000 ] = "RS4"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >110000 & rsdataord5$timefromfirsttrialonset <=113000 ] = "AG2"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >113000 & rsdataord5$timefromfirsttrialonset <=126000 ] = "RS5"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >126000 & rsdataord5$timefromfirsttrialonset <=139000 ] = "RS6"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >139001 & rsdataord5$timefromfirsttrialonset <=152000 ] = "RS7"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >152000 & rsdataord5$timefromfirsttrialonset <=155000 ] = "AG3"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >155000 & rsdataord5$timefromfirsttrialonset <=168000 ] = "RS8"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >168000 & rsdataord5$timefromfirsttrialonset <=181000 ] = "RS9"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >181000 & rsdataord5$timefromfirsttrialonset <=184000 ] = "AG4"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >184000 & rsdataord5$timefromfirsttrialonset <=197000 ] = "RS10"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >197000 & rsdataord5$timefromfirsttrialonset <=210000 ] = "RS11"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >210000 & rsdataord5$timefromfirsttrialonset <=223000 ] = "RS12"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >213000 & rsdataord5$timefromfirsttrialonset <=226000 ] = "AG5"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >226000 & rsdataord5$timefromfirsttrialonset <=239000 ] = "RS13"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >239000 & rsdataord5$timefromfirsttrialonset <=252000 ] = "RS14"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >252000 & rsdataord5$timefromfirsttrialonset <=255000 ] = "AG6"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >255000 & rsdataord5$timefromfirsttrialonset <=268000 ] = "RS15"
rsdataord5$trialtype[rsdataord5$timefromfirsttrialonset >268000 & rsdataord5$timefromfirsttrialonset <=272000 ] = "agwelldone"

# #this will be the same for all orders (but remember to change the timestamp to first value in $timefromfirsttrialonset)
retdataord5$timefromfirsttrialonset=retdataord5$timefromfirsttrialonset - retdataord5$timefromfirsttrialonset[1] +1#get timestamp for start of test value manually
head(retdataord5)
retdataord5$trialtype[retdataord5$timefromfirsttrialonset <= 7000 ] = "aghiret"
retdataord5$trialtype[retdataord5$timefromfirsttrialonset > 7000 & retdataord5$timefromfirsttrialonset <= 19500] = "reeng"
retdataord5$trialtype[retdataord5$timefromfirsttrialonset > 19500 & retdataord5$timefromfirsttrialonset <= 32000] = "ret1"
retdataord5$trialtype[retdataord5$timefromfirsttrialonset > 32000 & retdataord5$timefromfirsttrialonset <= 44500] = "ret2"
retdataord5$trialtype[retdataord5$timefromfirsttrialonset > 44500 & retdataord5$timefromfirsttrialonset <= 57000] = "ret3"
retdataord5$trialtype[retdataord5$timefromfirsttrialonset > 57000 & retdataord5$timefromfirsttrialonset <= 69500] = "ret4"
retdataord5$trialtype[retdataord5$timefromfirsttrialonset > 69500 & retdataord5$timefromfirsttrialonset <= 82000] = "ret5"
retdataord5$trialtype[retdataord5$timefromfirsttrialonset > 82000 & retdataord5$timefromfirsttrialonset <= 94500] = "ret6"


dataord5=rbind(rsdataord5, retdataord5)

#order 6####
rsdataord6 =subset(data, order %in% c("CC6", "VC6") & phase == "RS")
retdataord6 =subset(data, order %in% c("CC6", "VC6") & phase == "Ret")

rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset <= 7000 ] = "aghirs"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >7000 & rsdataord6$timefromfirsttrialonset <=23000 ] = "train1"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >23000 & rsdataord6$timefromfirsttrialonset <=39000 ] = "train2"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >39000 & rsdataord6$timefromfirsttrialonset <=55000 ] = "train3"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >55000 & rsdataord6$timefromfirsttrialonset <=68000 ] = "RS1"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >68000 & rsdataord6$timefromfirsttrialonset <=71000 ] = "AG1"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >71000 & rsdataord6$timefromfirsttrialonset <=84000 ] = "RS2"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >84000 & rsdataord6$timefromfirsttrialonset <=97000 ] = "RS3"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >97000 & rsdataord6$timefromfirsttrialonset <=110000 ] = "RS4"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >110000 & rsdataord6$timefromfirsttrialonset <=113000] = "AG2"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >113000 & rsdataord6$timefromfirsttrialonset <=126000 ] = "RS5"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >126000 & rsdataord6$timefromfirsttrialonset <=139000 ] = "RS6"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >139000 & rsdataord6$timefromfirsttrialonset <=142000 ] = "AG3"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >142000 & rsdataord6$timefromfirsttrialonset <=155000 ] = "RS7"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >155000 & rsdataord6$timefromfirsttrialonset <=168000 ] = "RS8"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >168000 & rsdataord6$timefromfirsttrialonset <=171000 ] = "AG4"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >171000 & rsdataord6$timefromfirsttrialonset <=184000 ] = "RS9"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >184000 & rsdataord6$timefromfirsttrialonset <=197000 ] = "RS10"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >197000 & rsdataord6$timefromfirsttrialonset <=210000 ] = "RS11"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >210000 & rsdataord6$timefromfirsttrialonset <=213000] = "AG5"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >213000 & rsdataord6$timefromfirsttrialonset <=226000 ] = "RS12"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >226000 & rsdataord6$timefromfirsttrialonset <=239000 ] = "RS13"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >239000 & rsdataord6$timefromfirsttrialonset <=242000 ] = "AG6"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >242000 & rsdataord6$timefromfirsttrialonset <=255000 ] = "RS14"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >255000 & rsdataord6$timefromfirsttrialonset <=268000 ] = "RS15"
rsdataord6$trialtype[rsdataord6$timefromfirsttrialonset >268000 & rsdataord6$timefromfirsttrialonset <=272000 ] = "agwelldone"

#this will be the same for all orders (but remember to change the timestamp to first value in $timefromfirsttrialonset)
retdataord6$timefromfirsttrialonset=retdataord6$timefromfirsttrialonset - retdataord6$timefromfirsttrialonset[1] +1#get timestamp for start of test value manually
head(retdataord6)
retdataord6$trialtype[retdataord6$timefromfirsttrialonset <= 7000 ] = "aghiret"
retdataord6$trialtype[retdataord6$timefromfirsttrialonset > 7000 & retdataord6$timefromfirsttrialonset <= 19500] = "reeng"
retdataord6$trialtype[retdataord6$timefromfirsttrialonset > 19500 & retdataord6$timefromfirsttrialonset <= 32000] = "ret1"
retdataord6$trialtype[retdataord6$timefromfirsttrialonset > 32000 & retdataord6$timefromfirsttrialonset <= 44500] = "ret2"
retdataord6$trialtype[retdataord6$timefromfirsttrialonset > 44500 & retdataord6$timefromfirsttrialonset <= 57000] = "ret3"
retdataord6$trialtype[retdataord6$timefromfirsttrialonset > 57000 & retdataord6$timefromfirsttrialonset <= 69500] = "ret4"
retdataord6$trialtype[retdataord6$timefromfirsttrialonset > 69500 & retdataord6$timefromfirsttrialonset <= 82000] = "ret5"
retdataord6$trialtype[retdataord6$timefromfirsttrialonset > 82000 & retdataord6$timefromfirsttrialonset <= 94500] = "ret6"

dataord6=rbind(rsdataord6, retdataord6)

#stick all the dataframes together again
data=rbind(dataord1, dataord2)
data=rbind(data, dataord3)
data=rbind(data, dataord4)
data=rbind(data, dataord5)
data=rbind(data, dataord6)

#check everything looks sensible. There should be data for all these cells
xtabs(~order, data)
xtabs(~trialtype, data)
xtabs(~pnum, data)
write.csv(data, "fmcol-data-2.csv")

#data=read.csv("fmcol-data-2.csv")

#code individual items#######
cbal=read.csv("fmcol-cbal.csv")#load the counterbalancing so we can code targets, competitors etc

head(data)
head(cbal)

xtabs(~order, data)
xtabs(~order, cbal)

datam=merge(cbal, data, by = c("order","trialtype","phase"), all.x=TRUE, all.y=TRUE)#add counterbalancing info to data
data=datam
xtabs(~target, data)#check it's worked - should be values for all the different objects.
write.csv(data,"fmcol-data-3.csv")

#add aoi information#######

# data=read.csv("fmcol-data-3.csv")

left_aoi = read.csv("left_aoi.csv")#AOI files created manually based on origianl AOIs in Tobii Studio.
middle_aoi = read.csv("middle_aoi.csv")
right_aoi = read.csv("right_aoi.csv")

tail(left_aoi)#check it looks OK

#this uses eyetrackingR to automatically code whether or not there's a hit in an AOI. You could also do this manually
data <-
  add_aoi(
    data = data,
    aoi_dataframe = left_aoi,
    x_col = "gazex",
    y_col = "gazey",
    aoi_name = "aoileft",
    x_min_col = "left",
    x_max_col = "right",
    y_min_col = "bottom",
    y_max_col = "top"
  ) #NB ymin and ymax opposite way round in how-to docs; check this if something goes wrong
data <-
  add_aoi(
    data = data,
    aoi_dataframe = middle_aoi,
    x_col = "gazex",
    y_col = "gazey",
    aoi_name = "aoimiddle",
    x_min_col = "left",
    x_max_col = "right",
    y_min_col = "bottom",
    y_max_col = "top"
  ) #NB ymin and ymax opposite way round in how-to docs; check this if something goes wrong
data <-
  add_aoi(
    data = data,
    aoi_dataframe = right_aoi,
    x_col = "gazex",
    y_col = "gazey",
    aoi_name = "aoiright",
    x_min_col = "left",
    x_max_col = "right",
    y_min_col = "bottom",
    y_max_col = "top"
  ) #NB ymin and ymax opposite way round in how-to docs; check this if something goes wrong
#
xtabs( ~ aoileft, data)#TRUE for look to that AOI, FALSE look elsewhere/no look
xtabs( ~ aoimiddle, data)
xtabs( ~ aoiright, data)

head(data)#check
write.csv(data, "fmcol-data-4.csv")

#tidy up data######
#data=read.csv("fmcol-data-4.csv")
data$X=NULL
head(data)

#only want training, RS and ret data
xtabs(~trialtype, data)
data=subset(data, trialtype %in% c("reeng", "train1","train2","train3","RS1","RS2","RS3","RS4","RS5","RS6","RS7","RS8","RS9","RS10","RS12","RS13","RS14","RS15","ret1","ret2","ret3","ret4","ret5","ret6"))
#
#code target hits
data$targhit = 0
data$targhit[data$targetpos == "left" & data$aoileft == TRUE] = 1
data$targhit[data$targetpos == "centre" & data$aoimiddle == TRUE] = 1
data$targhit[data$targetpos == "right" & data$aoiright == TRUE] = 1

xtabs(~pnum, data)
colnames(data)

#clean data and calculate number of rows excluded
nrowdataraw=nrow(data)
data = subset(data, validsum < 8)#exclude trials in which neither eye is reliably detected
nrowdataclean = nrow(data)
nbadrows = nrowdataraw - nrowdataclean
nbadrows#number of rows excluded
propgoodrows = nrowdataclean/nrowdataraw
propbadrows= 1-propgoodrows
propbadrows#proportion of rows excluded

#code known novel
data$novknown = NA
data$novknown[data$target %in% c("apple", "ball", "banana", "car", "cup", "fork")] = "known"
data$novknown[data$target %in% c("blick", "tife", "zorch")] = "novel"
xtabs(~novknown, data)

write.csv(data, "fmcol-data-5.csv") #this is the dataset with all trial types in (6 and 7 are just ret))

#rs data only#########
#data=read.csv("fmcol-data-5.csv")
head(data)
xtabs(~novknown+trialtype, data)#check there are no AG or retention trials here
datars=subset(data, trialtype %in% c("RS1","RS2","RS3","RS4","RS5","RS6","RS7","RS8","RS9","RS10","RS11","RS12","RS13","RS14","RS15"))
xtabs(~pnum, datars)
head(datars)

#code trial time relative to start of trial#####
#each child has a different starting value

datars$trialtime = NA
colnames(data)
xtabs(~pnum, data)

datars <- datars[order(datars$pnum, datars$timestamp),]#make sure data are sorted by timestamp within participant
head(data)

#this code will be very slow to run!
for (i in 1:nrow(datars)) {
  if (i == 1){
    startval = datars$timestamp[i]
    datars$trialtime[i] =1}
  else if(i > 1 & datars$trialtype[i] != datars$trialtype[i-1]) {#if it's the first timestamp
    startval = datars$timestamp[i]
    datars$trialtime[i] = datars$timestamp[i] - startval + 1}
  else if (i > 1 & datars$trialtype[i]== datars$trialtype[i-1]) {
    datars$trialtime[i] = datars$timestamp[i] - startval + 1
  }

}

head(datars)#check the first value in datars$trialtime is 1
max(datars$trialtime)#should be a big number
min(datars$trialtime)#should be 1
write.csv(datars, "fmcol-rsdata-1.csv")

#datars=read.csv("fmcol-rsdata-1.csv")

#code label onsets, discard non-aoi looks, check aois are correct#####
xtabs(~label1offset, datars)#different labels have different offsets (NB some labels have the same onset (ball/banana/blick) so makes more sense to use offset here)
datars$labeltime = NA
datars$labeltime = datars$trialtime - datars$label1offset#this column now has timestamps that are zero on label offset. some values will be negative (pre-label offset)

datarspost = subset(datars, labeltime > 233 & labeltime <= 6733)#analyse from offset of first label; audio clip is 5s; 1500 additional for reaction after audio clip finishes. leave 233 ms for saccade planning as per Swingley, Fernald & Pinto 1999 (NB this is controversial)

#exclude background looking
datarspost$aoileftn = ifelse(datarspost$aoileft == TRUE, 1, 0)#code AOI hits numerically
datarspost$aoirightn = ifelse(datarspost$aoiright == TRUE, 1, 0)
datarspost$aoimiddlen = ifelse(datarspost$aoimiddle == TRUE, 1, 0)

datarspost$aoihits=datarspost$aoileftn+datarspost$aoirightn+datarspost$aoimiddlen#make new column that adds these together (although it should never be more than 1 - children can't look at more than one AOI at one time)

datarspost = subset(datarspost, aoihits > 0)#discard non-aoi looks. our DV is going to be proportion AOI looking. This also means that there may be missing data for some time bins. This is not a problem for mixed effects models but if the plots don't cover the beginning/end of the trial this is why
datarspost$bin = floor(datarspost$labeltime/100)#make time bins. smaller bins will give more power for the analyses but messier plots

head(datarspost)

#plot gaze to check it looks sensible, e.g., AOIs are in the right place
p = ggplot(datarspost, aes(y = gazey, x=gazex, color = trialtime))
p = p + geom_point(size = 0.01)
p = p + scale_color_gradient(low = "blue", high = "yellow")
p = p + facet_wrap(~cond)
p = p + xlim(0,1920)
p = p + ylim(0,1080)
p = p + theme_bw()
p
ggsave("fmcol-aoicheck.pdf")#each point is an individual gaze point. more looking to center AOI overall. left-right positioning of objects/targets is pseudorandomized, so this is OK. Good to know though!
write.csv(datarspost, "fmcol-rsdata-2.csv")

#rs analyses########

#datarspost=read.csv("fmcol-rsdata-2.csv")
datarsmodel=aggregate(targhit~ novknown + cond + pnum + bin + target, datarspost, mean)#this is the dataset for the model. targhit gives you target looks
datarsttest=aggregate(targhit~ novknown + cond + pnum + bin, datarspost, mean)#this is the dataset for t-tests. targhit gives you proportion target looks. If you use the model dataset, which includes "target" so we can calculate random effects, then you get multiple measures per participant, which will make it look less variable than it is for the error bars.
xtabs(~target, datarspost)

#the following code calculates two-tailed t-tests against chance on proportion target looking for each time bin
#ret t-tests against chance###
head(datarsttest)
#make 4 subsets of the data, for CC/known. CC/novel. VC/known/VC/novel
datarscck=subset(datarsttest, cond == "CC" & novknown == "known")
datarsccn=subset(datarsttest, cond == "CC" & novknown == "novel")
datarsvck=subset(datarsttest, cond == "VC" & novknown == "known")
datarsvcn=subset(datarsttest, cond == "VC" & novknown == "novel")

#rs cc known t-tests#####
cckoutput=list()

for (i in 2:max(datarscck$bin)) {#for every bin
  j = subset(datarscck, bin == i)$targhit #make a separate subset of data from each ppt
  print(j) #print it to console so we know it's working
  cckoutput[i] = try(t.test(j, alternative = "two.sided", mu = 0.33)[3])#then >ith row, 2nd column of >output is the p-value (3rd element of the t.test function output) of a two-tailed t-test against chance. NB: >try means it keeps going if it hits an error, and prints the error output to >output
}
cckoutput

pvalscck=data.frame(unlist(cckoutput))
pvalscck$bin = NA
colnames(pvalscck)=c("pval","bin")
pvalscck$bin=c(1:nrow(pvalscck))
head(pvalscck)
is.numeric(pvalscck$pval)

pvalsccksig=pvalscck
pvalsccksig$sig=NA
pvalsccksig$sig[pvalsccksig$pval > 0.05] = 0
pvalsccksig$sig[pvalsccksig$pval <= 0.05] = 1
xtabs(~sig, pvalsccksig)
datarscck=merge(pvalsccksig, datarscck, by="bin")
tail(datarscck)#do this for all of the four subsets then put them back together

#rs cc novel t-tests#####
ccnoutput=list()
for (i in 2:max(datarsccn$bin)) {#for every bin
  j = subset(datarsccn, bin == i)$targhit #make a separate subset of data from each ppt
  print(j) #print it to console so we know it's working
  ccnoutput[i] = try(t.test(j, alternative = "two.sided", mu = 0.33)[3])#then >ith row, 2nd column of >output is the p-value (3rd element of the t.test function output) of a two-tailed t-test against chance. NB: >try means it keeps going if it hits an error, and prints the error output to >output
}
ccnoutput

pvalsccn=data.frame(unlist(ccnoutput))
pvalsccn$bin = NA
colnames(pvalsccn)=c("pval","bin")
pvalsccn$bin=c(1:nrow(pvalsccn))
head(pvalsccn)
is.numeric(pvalsccn$pval)

#check manually for errors by inspecting pvals df for error messages
pvalsccnsig=pvalsccn
pvalsccnsig$sig=NA
pvalsccnsig$sig[pvalsccnsig$pval > 0.05] = 0
pvalsccnsig$sig[pvalsccnsig$pval <= 0.05] = 1
xtabs(~sig, pvalsccnsig)
datarsccn=merge(pvalsccnsig, datarsccn, by="bin")
head(datarsccn)


#rs vc known t-tests#####
vckoutput=list()
for (i in 2:max(datarsvck$bin)) {#for every bin
  j = subset(datarsvck, bin == i)$targhit #make a separate subset of data from each ppt
  print(j) #print it to console so we know it's working
  vckoutput[i] = try(t.test(j, alternative = "two.sided", mu = 0.33)[3])#then >ith row, 2nd column of >output is the p-value (3rd element of the t.test function output) of a two-tailed t-test against chance. NB: >try means it keeps going if it hits an error, and prints the error output to >output
}
vckoutput

pvalsvck=data.frame(unlist(vckoutput))
pvalsvck$bin = NA
colnames(pvalsvck)=c("pval","bin")
pvalsvck$bin=c(1:nrow(pvalsvck))
head(pvalsvck)

is.numeric(pvalsvck$pval)

#check manually for errors by inspecting pvals df for error messages
pvalsvcksig=pvalsvck
pvalsvcksig$sig=NA
pvalsvcksig$sig[pvalsvcksig$pval > 0.05] = 0
pvalsvcksig$sig[pvalsvcksig$pval <= 0.05] = 1
xtabs(~sig, pvalsvcksig)
datarsvck=merge(pvalsvcksig, datarsvck, by="bin")
head(datarsvck)#

#rs vc novel t-tests#####
vcnoutput=list()
for (i in 2:max(datarsvcn$bin)) {#for every bin
  j = subset(datarsvcn, bin == i)$targhit #make a separate subset of data from each ppt
  print(j) #print it to console so we know it's working
  vcnoutput[i] = try(t.test(j, alternative = "two.sided", mu = 0.33)[3])#then >ith row, 2nd column of >output is the p-value (3rd element of the t.test function output) of a two-tailed t-test against chance. NB: >try means it keeps going if it hits an error, and prints the error output to >output
}
vcnoutput

pvalsvcn=data.frame(unlist(vcnoutput))
pvalsvcn$bin = NA
colnames(pvalsvcn)=c("pval","bin")
pvalsvcn$bin=c(1:nrow(pvalsvcn))
head(pvalsvcn)

is.numeric(pvalsvcn$pval)

#check manually for errors by inspecting pvals df for error messages
pvalsvcnsig=pvalsvcn
pvalsvcnsig$sig=NA
pvalsvcnsig$sig[pvalsvcnsig$pval > 0.05] = 0
pvalsvcnsig$sig[pvalsvcnsig$pval <= 0.05] = 1
xtabs(~sig, pvalsvcnsig)
datarsvcn=merge(pvalsvcnsig, datarsvcn, by="bin")
head(datarsvcn)#

datars_p=rbind(datarscck,datarsccn)
datars_p=rbind(datars_p, datarsvck)
datars_p=rbind(datars_p, datarsvcn)

head(datars_p)#this data frame has p values for each time bin for each trial type
write.csv(datars_p, "fmcol-rsdata-ttests.csv")#use this dataset for plotting

#RS mixed effects model#####
paste(attr(terms(as.formula(DV ~ bin * novknown * cond)),which="term.labels"), collapse=" + ")#this code gives you the correct order for the terms in the mixed model

#build basic model by adding terms one by one
model1=lmer(targhit ~ 1 + (1 |pnum) + (1|target), datarsmodel)
model2=lmer(targhit ~ bin + (1 |pnum) + (1|target), datarsmodel)
model3=lmer(targhit ~ bin + novknown + (1 |pnum) + (1|target), datarsmodel)
model4=lmer(targhit ~ bin + novknown + cond + (1 |pnum) + (1|target), datarsmodel)
model5=lmer(targhit ~ bin + novknown + cond + bin:novknown + (1 |pnum) + (1|target), datarsmodel)
model6=lmer(targhit ~ bin + novknown + cond + bin:novknown + bin:cond + (1 |pnum) + (1|target), datarsmodel)
model7=lmer(targhit ~ bin + novknown + cond + bin:novknown + bin:cond + novknown:cond + (1 |pnum) + (1|target), datarsmodel)
modelfull=lmer(targhit ~ bin + novknown + cond + bin:novknown + bin:cond + novknown:cond + bin:novknown:cond + (1 |pnum) + (1 |target), datarsmodel)

#likelhood ratio test to test fixed effects. This is sequential type I sum of squares which I believe is the most conservative way to do it (because each chunk of variance is only used once). THE DF SHOULD ALWAYS BE 1 because the models should be nested - we test each fixed effect in turn from the simplest up, without replacement. Note that there are other ways of doing this but as far as I know this is considered the most conservative
anova(model1, model2)#test bin
anova(model2, model3)#test novknown
anova(model3, model4)#test cond
anova(model4, model5)#test bin:novknown
anova(model5, model6)#test bin:cond
anova(model6, model7)#test novknown:cond
anova(model7, modelfull)#test 3 way interacton

#add random effects as appropriate for the data. This is the Bates et al. approach; Rob Davies recommends this way.
# (1 + cond | num): random variation by participant for condition accounts for different children having different a priori levels of color attention
# (1 + bin | pnum): random variation by participant for bin accounts for different children having different attention spans
# (1 + novnum | pnum): random variation by participant for trial type accounts for different children having different reactions to the novel label
#(1 | target): random intercepts for target accounts for different salience/familiarity of targets

modelfullmax=lmer(targhit ~ bin + novknown + cond + bin:novknown + bin:cond + novknown:cond + bin:novknown:cond + (1 + cond + bin + novknown | pnum) + (1 |target), datarsmodel)
summary(modelfullmax)#this model doesn't converge

#simplify by taking out highest order random effect that explains least variance
modelfullmax=lmer(targhit ~ bin + novknown + cond + bin:novknown + bin:cond + novknown:cond + bin:novknown:cond + (1 + bin + novknown | pnum) + (1 |target), datarsmodel)
summary(modelfullmax)

modelfullmax=lmer(targhit ~ bin + novknown + cond + bin:novknown + bin:cond + novknown:cond + bin:novknown:cond + (1 + bin  | pnum) + (1 |target), datarsmodel)
summary(modelfullmax)

modelfullmax=lmer(targhit ~ bin + novknown + cond + bin:novknown + bin:cond + novknown:cond + bin:novknown:cond + (1 | pnum) + (1 |target), datarsmodel)
#max model just has random intercepts for subjects and items.
#check these for contribution to model - only keep them if the likelihood ratio test is significant

modelfullr1=lmer(targhit ~ bin + novknown + cond + bin:novknown + bin:cond + novknown:cond + bin:novknown:cond +(1 |target), datarsmodel)#this has no by particiant intercepts
modelfullr2=lmer(targhit ~ bin + novknown + cond + bin:novknown + bin:cond + novknown:cond + bin:novknown:cond + (1 | pnum) , datarsmodel)#this has no by target intercepts

anova(modelfull, modelfullr1)#compare the full model to the no participant intercepts model
anova(modelfull, modelfullr2)#compare the full model to the no target intercepts model

#keep both random effects. If this random effects strucutre were different to the model above, we'd have to rerun the full model with the new random effects, and redo the model comparisons (the likelihood ratio test, LRT). Luckily, it's the same, so we can keep "modelfull" as out main model. we report the betas, SEs, t from
summary(modelfull)
#and the chi-sq, df, and p value from the LRTs.

#RS mixed models by condition######
#the three-way interaction was signigicant, so split data by condition and run new mixed models on each condition separately
#CC
datarsCC=subset(datarsmodel, cond == c("CC"))#just the CC data
modelCC1=lmer(targhit ~ 1 + (1|pnum) + (1|target), datarsCC)#keep same random effects structure as above. I'm not sure whether this is right, but if we're asked about it we can test the same random effects as above
modelCC2=lmer(targhit ~ bin + (1|pnum) + (1|target), datarsCC)
modelCC3=lmer(targhit ~ bin + novknown + (1|pnum) + (1|target), datarsCC)
modelCCfull=lmer(targhit ~ bin * novknown + (1|pnum) + (1|target), datarsCC)
summary(modelCCfull)

anova(modelCC1, modelCC2)#test bin. Main effect of bin
anova(modelCC2, modelCC3)#test trialtype. No effect of trial type.
anova(modelCC3, modelCCfull)#test interaction. No interaction.
#no need to analyse any further.

#VC
datarsVC=subset(datarsmodel, cond == c("VC"))
modelVC1=lmer(targhit ~ 1 + (1|pnum) + (1|target), datarsVC)
modelVC2=lmer(targhit ~ bin + (1|pnum) + (1|target), datarsVC)
modelVC3=lmer(targhit ~ bin + novknown  + (1|pnum) + (1|target), datarsVC)
modelVCfull=lmer(targhit ~ bin * novknown  + (1|pnum) + (1|target), datarsVC)

summary(modelVCfull)

anova(modelVC1, modelVC2)#test bin. Main effect of bin
anova(modelVC2, modelVC3)#test trial type. No effect of trial type
anova(modelVC3, modelVCfull)#test interaction. Significant interaction, so...

#explore binnovknown interaction in VC: split by novknown for VC
datarsVCknown = subset(datarsVC, novknown == c("known"))
modelVCknown1 = lmer(targhit ~ 1 + (1|pnum) + (1|target),datarsVCknown)
modelVCknown = lmer(targhit ~ bin + (1|pnum) + (1|target),datarsVCknown)
anova(modelVCknown,modelVCknown1)
summary(modelVCknown)#looking increases over time (beta = 0.0036)

datarsVCnovel = subset(datarsVC, novknown == c("novel"))
modelVCnov1 = lmer(targhit ~ 1 + (1|pnum) + (1|target),datarsVCnovel)
modelVCnov = lmer(targhit ~ bin + (1|pnum) + (1|target),datarsVCnovel)
anova(modelVCnov,modelVCnov1)
summary(modelVCnov)#looking increases over time (beta = 0.0019). So, the interaction means that looking in the VC condition increases faster for known than novel trials.


#the code below splits the data by known and novel trials, in case we're asked for it. The story's not that strong whichever way you split it, and it wouldn't change our conclusions. Basically they're pretty rubbish at RS, but get better as the trial goes on.
# datarsknown=subset(datarsmodel, novknown == c("known"))
# modelknown1=lmer(targhit ~ 1 + (1|pnum) + (1|target), datarsknown)
# modelknown2=lmer(targhit ~ bin + (1|pnum) + (1|target), datarsknown)
# modelknown3=lmer(targhit ~ bin + cond + (1|pnum) + (1|target), datarsknown)
# modelknownfull=lmer(targhit ~ bin * cond + (1|pnum) + (1|target), datarsknown)
# summary(modelknownfull)
#
# anova(modelknown1, modelknown2)#test bin
# anova(modelknown2, modelknown3)#test trialtype
# anova(modelknown3, modelknownfull)#test trialtype
#
# datarsnovel=subset(datarsmodel, novknown == c("novel"))
# modelnovel1=lmer(targhit ~ 1 + (1|pnum) + (1|target), datarsnovel)
# modelnovel2=lmer(targhit ~ bin + (1|pnum) + (1|target), datarsnovel)
# modelnovel3=lmer(targhit ~ bin + cond + (1|pnum) + (1|target), datarsnovel)
# modelnovelfull=lmer(targhit ~ bin * cond + (1|pnum) + (1|target), datarsnovel)
# summary(modelnovelfull)
#
# anova(modelnovel1, modelnovel2)#test bin
# anova(modelnovel2, modelnovel3)#test trialtype
# anova(modelnovel3, modelnovelfull)#test trialtype


#RS plots#####
plotdata=read.csv("fmcol-rsdata-ttests.csv")#use the dataset for the t-tests which don't include the target variable
head(plotdata)
xtabs(~sig, plotdata)
plotdata$sig

source("summarySE.R")#load a piece of code that automatically calculates confidence intervals (also SEs if you want them)
plotdata=summarySE(plotdata, measurevar = "targhit", groupvars = c("bin","novknown","cond","sig"))
plotdata$sig2[plotdata$sig == 1] = 50#make a new column that you can use to control the dots that mark significant time bins. 50 is an arbitrary number, but the NAs are important.
plotdata$sig2[plotdata$sig == 0] = NA
plotdata$sig2=as.factor(plotdata$sig2)

#All the corrections I can find in the literature (eg Borovsky) are for paired t-tests, not t-tests against chance. Makes sense because chance t-tests are planned (?). Let's report them and see what reviewers say.

#CC Plot
p = ggplot(subset(plotdata, cond == "CC"), aes(y = targhit, x = bin, colour= novknown, linetype = novknown))
p = p + geom_line()#add the line
p = p + geom_point(aes(shape = sig2), size = 3)#add the points, which only appear when there's a value in plotdata$sig2 (it's either 50 or NA)
p = p + ylab("Proportion target looking\n")#y axis label
cbPalette <- c("#E69F00", "#336699", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")#color palette that's supposedly colour blind friendly!
p = p + scale_color_manual(values=cbPalette)#tell it to use that palette
p = p + theme_bw()#a theme which gets rid of grayscale, for APA format
p = p + theme(legend.key = element_rect(colour="white"))#get rid of box around legend
p = p + theme(panel.border= element_blank())#get rid of box around plot area
p = p + theme(panel.grid.minor=element_blank(), panel.grid.major=element_blank())#get rid of gridlines
p = p + guides(shape=FALSE)#get rid of extra legend for shape
p = p + theme(axis.line.x=element_line(colour="black"))#put x axis back in
p = p + theme(axis.line.y=element_line(colour="black"))#put y axis back in
p = p + theme(legend.key = element_rect(colour="white"))
p = p + xlab("\nSeconds after label offset")#x axis label
p = p+theme(legend.position="bottom")#put legend at bottom of plot
p = p + labs(color='Trial type', linetype = 'Trial type')#correct legend titls
p = p + geom_errorbar(aes(ymin=targhit-ci, ymax=targhit+ci),size=.3, width=.2)#add error bars
p = p +  geom_hline(yintercept=c(0.33), linetype="longdash")#add line for chance
p = p + scale_x_continuous(breaks = c(0,10,20,30,40,50,60,70,80,90,100), labels = c(0,1,2,3,4,5,6,7,8,9,10))#force scale to be in seconds
p
ggsave("RSCC.tiff", width = 8, height = 4, dpi = 500)#save a tiff. you can change the file type, e.g. replace .tiff with .pdf. Also you can play around with the width and height to get the font sizes right
#
#VC plot
p = ggplot(subset(plotdata, cond == "VC"), aes(y = targhit, x = bin, colour= novknown, linetype = novknown))
p = p + geom_line()
p = p + geom_point(aes(shape = sig2), size = 3)
p = p + ylab("Proportion target looking\n")
cbPalette <- c("#E69F00", "#336699", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")
p = p + scale_color_manual(values=cbPalette)
p = p + theme_bw()
p = p + theme(legend.key = element_rect(colour="white"))
p = p + theme(panel.border= element_blank())
p = p + theme(panel.grid.minor=element_blank(), panel.grid.major=element_blank())
p = p + guides(shape=FALSE)
p = p + theme(axis.line.x=element_line(colour="black"))
p = p + theme(axis.line.y=element_line(colour="black"))
p = p + theme(panel.border= element_blank())
p = p + xlab("\nSeconds after label offset")
p = p+theme(legend.position="bottom")
p = p + labs(color='Trial type', linetype = 'Trial type')
p = p + geom_errorbar(aes(ymin=targhit-ci, ymax=targhit+ci),size=.3, width=.2)
p = p +  geom_hline(yintercept=c(0.33), linetype="longdash")
p = p + scale_x_continuous(breaks = c(0,10,20,30,40,50,60,70,80,90,100), labels = c(0,1,2,3,4,5,6,7,8,9,10))
p
ggsave("RSVC.tiff", width = 8, height = 4, dpi = 500)


#test trial data only#############################

#data = read.csv("fmcol-data-5.csv")
dataret = subset(data, trialtype %in% c("ret1", "ret2", "ret3", "ret4", "ret5", "ret6"))#just the retention trials
#
dataret$trialtime = NA#make a column for trial time
head(dataret)

dataret <- dataret[order(dataret$pnum, dataret$timestamp), ]#sort by timestamp. IMPORTANT

#code time from beginning of trial. will take a while to run
for (i in 1:nrow(dataret)) {
  if (i == 1) {
    startval = dataret$timestamp[i]
    dataret$trialtime[i] = 1
  }
  else if (i > 1 &
           dataret$trialtype[i] != dataret$trialtype[i - 1]) {
    #if it's the first timestamp
    startval = dataret$timestamp[i]
    dataret$trialtime[i] = dataret$timestamp[i] - startval + 1
  }
  else if (i > 1 & dataret$trialtype[i] == dataret$trialtype[i - 1]) {
    dataret$trialtime[i] = dataret$timestamp[i] - startval + 1
  }
}

head(dataret)#check the first element of trialtime is 1, next is 18, etc. if not, restart from the top of this section. v important!

xtabs(~label1offset, dataret)#label offsets are the same as for the RS phase
dataret$labeltime = dataret$trialtime - dataret$label1offset#this column now has timestamps that are zero on label offset

dataretpost = subset(dataret, labeltime > 233 & labeltime < 6733)#not all labels have same offset so analyse until end of trial from offset of first label;
#labelling starts at ~4s; trials are 13s long, so it makes sense that there's ~9s to the end of the trial. Allow 233ms for saccade preparation
head(dataretpost)
#
#exclude background looking
dataretpost$aoileftn = ifelse(dataretpost$aoileft == TRUE, 1, 0)
dataretpost$aoirightn = ifelse(dataretpost$aoiright == TRUE, 1, 0)
dataretpost$aoimiddlen = ifelse(dataretpost$aoimiddle == TRUE, 1, 0)
dataretpost$aoihits=dataretpost$aoileftn+dataretpost$aoirightn+dataretpost$aoimiddlen
dataretpost = subset(dataretpost, aoihits > 0)#this means we're only interested in proportion AOI looking
dataretpost$bin = floor(dataretpost$labeltime/100)

means=aggregate(targhit ~ cond + pnum, dataretpost, mean)
t.test(targhit ~ cond, means)#this t-test tells us there's more looking in VC than CC. But we don't report it, as this is what the mixed model also tells us

write.csv(dataretpost, "fmcol-data-ret-times.csv")

#dataretpost = read.csv("fmcol-data-ret-times.csv")
head(dataretpost)
xtabs(~trialtype, dataretpost)#check there are only ret trials

#we want to separate the memory reactivation trials from the retention trials
dataretpost$retblock = ifelse(dataretpost$trialtype %in% c("ret1","ret2","ret3"),1,2)#if it's a memory reactivation trial, put 1 in datretpost$retblock, otherwise put a 2

xtabs(~retblock, dataretpost)#these won't be equal as children will have lost interest later on in the retention phase. We're interested in proportions, though, so this is OK

datatestmodel=aggregate(targhit~ novknown + cond + pnum + bin + target + retblock, dataretpost, mean)#dataset for the mixed model

#the following code analyses all 6 test trials together. It shows a main effect of retention block. We don't report this, to keep things simple, but it's good to have it if we're asked for it.

# retmodelall=lmer(targhit ~ bin * cond * retblock + (1 + retblock | pnum) + (1| target), datatestmodel)#doesn't converge so remove highest order random effects which account for least variance
# summary(retmodelall)
# #
# retmodelall1=lmer(targhit ~ 1 + (1 + retblock | pnum) + (1 | target), datatestmodel)
# retmodelall2=lmer(targhit ~ bin + (1 + retblock | pnum) + (1 | target), datatestmodel)
# retmodelall3=lmer(targhit ~ bin + cond + (1 + retblock | pnum) + (1  | target), datatestmodel)
# retmodelall4=lmer(targhit ~ bin + cond + retblock  + (1 + retblock | pnum) + (1 | target), datatestmodel)
# retmodelall5=lmer(targhit ~ bin + cond + retblock + bin:cond  + (1+ retblock | pnum) + (1 | target), datatestmodel)
# retmodelall6=lmer(targhit ~ bin + cond + retblock + bin:cond + bin:retblock + (1 + retblock | pnum) + (1 | target), datatestmodel)
# retmodelall7=lmer(targhit ~ bin + cond + retblock + bin:cond + bin:retblock + cond:retblock + (1 + retblock | pnum) + (1 | target), datatestmodel)
# retmodelfull=retmodelall
#
# anova(retmodelall1,retmodelall2)#test bin
# anova(retmodelall2,retmodelall3)#test condition
# anova(retmodelall3,retmodelall4)#test retblock
# anova(retmodelall4,retmodelall5)#test bin:cond
# anova(retmodelall5,retmodelall6)#test bin:retblock
# anova(retmodelall6,retmodelall7)#test cond:retblock
# anova(retmodelall7,retmodelfull)#test 3 way
#
data_test_ttest=aggregate(targhit~ novknown + cond + pnum + bin + retblock, dataretpost, mean)
#
#memory reactivation trials#######
datamemttest = subset(data_test_ttest, retblock == 1)
xtabs(~retblock, datamemttest)#make sure there's only values for retblock=1

#t=tests against chance: separate by condition
datamrcc=subset(datamemttest, cond == "CC")
datamrvc=subset(datamemttest, cond == "VC")

#memory reactivation cc t-tests#####
ccmroutput=list()
for (i in 2:max(datamrcc$bin)) {#for every bin
  j = subset(datamrcc, bin == i)$targhit #make a separate subset of data from each ppt
  print(j) #print it to console so we know it's working
  ccmroutput[i] = try(t.test(j, alternative = "two.sided", mu = 0.33)[3])#then >ith row, 2nd column of >output is the p-value (3rd element of the t.test function output) of a two-tailed t-test against chance. NB: >try means it keeps going if it hits an error, and prints the error output to >output
}

ccmroutput
pvalsmrcc=data.frame(unlist(ccmroutput))
pvalsmrcc$bin = NA
colnames(pvalsmrcc)=c("pval","bin")
pvalsmrcc$bin=c(1:nrow(pvalsmrcc))
head(pvalsmrcc)
is.numeric(pvalsmrcc$pval)

#check manually for errors by inspecting pvals df for error messages
pvalsmrccsig=pvalsmrcc
pvalsmrccsig$sig=NA
pvalsmrccsig$sig[pvalsmrccsig$pval > 0.05] = 0
pvalsmrccsig$sig[pvalsmrccsig$pval <= 0.05] = 1
xtabs(~sig, pvalsmrccsig)
datamrcc=merge(pvalsmrccsig, datamrcc, by="bin")
head(datamrcc)#

#memory reactivation vc t-tests#####
vcmroutput=list()
for (i in 2:max(datamrvc$bin)) {#for every bin
  j = subset(datamrvc, bin == i)$targhit #make a separate subset of data from each ppt
  print(j) #print it to console so we know it's working
  vcmroutput[i] = try(t.test(j, alternative = "two.sided", mu = 0.33)[3])#then >ith row, 2nd column of >output is the p-value (3rd element of the t.test function output) of a two-tailed t-test against chance. NB: >try means it keeps going if it hits an error, and prints the error output to >output
}

vcmroutput
pvalsmrvc=data.frame(unlist(vcmroutput))
pvalsmrvc$bin = NA
colnames(pvalsmrvc)=c("pval","bin")
pvalsmrvc$bin=c(1:nrow(pvalsmrvc))
head(pvalsmrvc)
is.numeric(pvalsmrvc$pval)

#check manually for errors by inspecting pvals df for error messages
pvalsmrvcsig=pvalsmrvc
pvalsmrvcsig$sig=NA
pvalsmrvcsig$sig[pvalsmrvcsig$pval > 0.05] = 0
pvalsmrvcsig$sig[pvalsmrvcsig$pval <= 0.05] = 1
xtabs(~sig, pvalsmrvcsig)
datamrvc=merge(pvalsmrvcsig, datamrvc, by="bin")
head(datamrvc)#

datamr_ttest=rbind(datamrcc, datamrvc)

#memory reactivation plot####

source("summarySE.R")
plotdatamemreact=summarySE(datamr_ttest, measurevar = "targhit", groupvars = c("bin","sig","cond"))
plotdatamemreact$sig2[plotdatamemreact$sig == 1] = 50
plotdatamemreact$sig2[plotdatamemreact$sig == 0] = NA
plotdatamemreact$sig2=as.factor(plotdatamemreact$sig2)

plotdatamemreact$cond = ifelse(plotdatamemreact$cond == "CC", "Constant", "Variable")#recode condition column so it has the full condition names for the plot. There are other ways of doing this, but this is a quick way.

p = ggplot(plotdatamemreact, aes(y = targhit, x = bin, colour= cond, linetype = cond))
p = p + geom_line()
p = p + geom_point(aes(shape = sig2, size = sig2))
p = p + ylab("Proportion target looking\n")
cbPalette <- c("#999999", "#009E73","#F0E442", "#0072B2", "#D55E00")
p = p + scale_color_manual(values=cbPalette)
p = p + theme_bw()
p = p + theme(panel.border= element_blank())
p = p + theme(axis.line=element_line(colour="black"))
p = p + theme(panel.grid.minor=element_blank(), panel.grid.major=element_blank())
p = p + guides(shape = FALSE, size = FALSE)
p = p + theme(axis.line.x=element_line(colour="black"))
p = p + theme(axis.line.y=element_line(colour="black"))
p = p + theme(legend.key = element_rect(colour = "white"))
p = p + theme(panel.border= element_blank())
p = p + xlab("\nSeconds after label offset")
p = p + geom_errorbar(aes(ymin=targhit-ci, ymax=targhit+ci),size=.3, width=.2)
p = p +  geom_hline(yintercept=c(0.33), linetype="longdash")
p = p + scale_x_continuous(breaks = c(0,10,20,30,40,50,60,70,80,90,100), labels = c(0,1,2,3,4,5,6,7,8,9,10))
p = p + labs(color='Condition', linetype = 'Condition')
p
ggsave("memoryreactivation.tiff", width = 8, height = 4, dpi = 500)

#memory reactivation mixed effects models######
datamemreact=subset(datatestmodel, retblock ==1)
memreactmodel=lmer(targhit ~ bin * cond + (1 + bin * cond | pnum) + (1 + bin * cond | target), datamemreact)#doesn't converge so remove highest order random effects which account for least variance; keep going until it converges
summary(memreactmodel)

memreactmodela=lmer(targhit ~ bin * cond + (1 + bin + cond | pnum) + (1 + bin * cond | target), datamemreact)
summary(memreactmodela)

memreactmodelb=lmer(targhit ~ bin * cond + (1 + bin + cond | pnum) + (1 + bin + cond | target), datamemreact)
summary(memreactmodelb)

memreactmodelc=lmer(targhit ~ bin * cond + (1 + cond | pnum) + (1 + bin + cond | target), datamemreact)
summary(memreactmodelc)

memreactmodeld=lmer(targhit ~ bin * cond + (1 + cond | pnum) + (1 + cond | target), datamemreact)
summary(memreactmodeld)

memreactmodele=lmer(targhit ~ bin * cond + (1 + cond | pnum) + (1 | target), datamemreact)
summary(memreactmodele)

memreactmodelf=lmer(targhit ~ bin * cond + (1 | pnum) + (1 | target), datamemreact)
summary(memreactmodelf)#while model e and f converge, their nested models don't, which makes it impossible to test the fixed effects. So, remove random effects until all nested models converge. The eventual random effects structure is the same as the original model.

memreactmodelfull=memreactmodelf

memreactmodel1=lmer(targhit ~ 1 + (1  | pnum) + (1 | target), datamemreact)
memreactmodel2=lmer(targhit ~ bin + (1  | pnum) + (1 | target), datamemreact)
memreactmodel3=lmer(targhit ~ cond + bin + (1| pnum) + (1 | target), datamemreact)

anova(memreactmodel1, memreactmodel2)# test bin. main effect of bin
anova(memreactmodel2, memreactmodel3)# test condition. no main effect of condition
anova(memreactmodel3, memreactmodelfull)# test interaction. no interaction
summary(memreactmodelfull)











#retention trials#######
dataretttest = subset(data_test_ttest, retblock == 2)
xtabs(~retblock, dataretttest)#make sure there's only values for retblock=1

#t=tests against chance: separate by condition
dataretcc=subset(dataretttest, cond == "CC")
dataretvc=subset(dataretttest, cond == "VC")

#retention cc t-tests#####
ccretoutput=list()
for (i in 2:max(dataretcc$bin)) {#for every bin
  j = subset(dataretcc, bin == i)$targhit #make a separate subset of data from each ppt
  print(j) #print it to console so we know it's working
  ccretoutput[i] = try(t.test(j, alternative = "two.sided", mu = 0.33)[3])#then >ith row, 2nd column of >output is the p-value (3rd element of the t.test function output) of a two-tailed t-test against chance. NB: >try means it keeps going if it hits an error, and prints the error output to >output
}

ccretoutput
pvalsretcc=data.frame(unlist(ccretoutput))
pvalsretcc$bin = NA
colnames(pvalsretcc)=c("pval","bin")
pvalsretcc$bin=c(1:nrow(pvalsretcc))
head(pvalsretcc)
is.numeric(pvalsretcc$pval)

#check manually for errors by inspecting pvals df for error messages
pvalsretccsig=pvalsretcc
pvalsretccsig$sig=NA
pvalsretccsig$sig[pvalsretccsig$pval > 0.05] = 0
pvalsretccsig$sig[pvalsretccsig$pval <= 0.05] = 1
xtabs(~sig, pvalsretccsig)
dataretcc=merge(pvalsretccsig, dataretcc, by="bin")
head(dataretcc)#

#retention vc t-tests#####
vcretoutput=list()
for (i in 2:max(dataretvc$bin)) {#for every bin
  j = subset(dataretvc, bin == i)$targhit #make a separate subset of data from each ppt
  print(j) #print it to console so we know it's working
  vcretoutput[i] = try(t.test(j, alternative = "two.sided", mu = 0.33)[3])#then >ith row, 2nd column of >output is the p-value (3rd element of the t.test function output) of a two-tailed t-test against chance. NB: >try means it keeps going if it hits an error, and prints the error output to >output
}

vcretoutput
pvalsretvc=data.frame(unlist(vcretoutput))
pvalsretvc$bin = NA
colnames(pvalsretvc)=c("pval","bin")
pvalsretvc$bin=c(1:nrow(pvalsretvc))
head(pvalsretvc)
is.numeric(pvalsretvc$pval)

#check manually for errors by inspecting pvals df for error messages
pvalsretvcsig=pvalsretvc
pvalsretvcsig$sig=NA
pvalsretvcsig$sig[pvalsretvcsig$pval > 0.05] = 0
pvalsretvcsig$sig[pvalsretvcsig$pval <= 0.05] = 1
xtabs(~sig, pvalsretvcsig)
dataretvc=merge(pvalsretvcsig, dataretvc, by="bin")
head(dataretvc)#

dataret_ttest=rbind(dataretcc, dataretvc)

#retention plot####

source("summarySE.R")
plotdataret=summarySE(dataret_ttest, measurevar = "targhit", groupvars = c("bin","sig","cond"))
plotdataret$sig2[plotdataret$sig == 1] = 50
plotdataret$sig2[plotdataret$sig == 0] = NA
plotdataret$sig2=as.factor(plotdataret$sig2)

plotdataret$cond = ifelse(plotdataret$cond == "CC", "Constant", "Variable")#recode condition column so it has the full condition names for the plot. There are other ways of doing this, but this is a quick way.

p = ggplot(plotdataret, aes(y = targhit, x = bin, colour= cond, linetype = cond))
p = p + geom_line()
p = p + geom_point(aes(shape = sig2, size = sig2))
p = p + ylab("Proportion target looking\n")
cbPalette <- c("#999999", "#009E73","#F0E442", "#0072B2", "#D55E00")
p = p + scale_color_manual(values=cbPalette)
p = p + theme_bw()
p = p + theme(panel.border= element_blank())
p = p + theme(axis.line=element_line(colour="black"))
p = p + theme(panel.grid.minor=element_blank(), panel.grid.major=element_blank())
p = p + guides(shape = FALSE, size = FALSE)
p = p + theme(axis.line.x=element_line(colour="black"))
p = p + theme(axis.line.y=element_line(colour="black"))
p = p + theme(legend.key = element_rect(colour = "white"))
p = p + theme(panel.border= element_blank())
p = p + xlab("\nSeconds after label offset")
p = p + geom_errorbar(aes(ymin=targhit-ci, ymax=targhit+ci),size=.3, width=.2)
p = p +  geom_hline(yintercept=c(0.33), linetype="longdash")
p = p + scale_x_continuous(breaks = c(0,10,20,30,40,50,60,70,80,90,100), labels = c(0,1,2,3,4,5,6,7,8,9,10))
p = p + labs(color='Condition', linetype = 'Condition')
p
ggsave("retention.tiff", width = 8, height = 4, dpi = 500)

#retention mixed effects models######
dataret=subset(datatestmodel, retblock == 2)
retmodel=lmer(targhit ~ bin * cond + (1 + bin * cond | pnum) + (1 + bin * cond | target), dataret)#doesn't converge so remove highest order random effects which account for least variance; keep going until it converges
summary(retmodel)

retmodela=lmer(targhit ~ bin * cond + (1 + bin + cond | pnum) + (1 + bin * cond | target), dataret)
summary(retmodela)

retmodelb=lmer(targhit ~ bin * cond + (1 + bin + cond | pnum) + (1 + bin + cond | target), dataret)
summary(retmodelb)

retmodelc=lmer(targhit ~ bin * cond + (1 + cond | pnum) + (1 + bin + cond | target), dataret)
summary(retmodelc)

retmodeld=lmer(targhit ~ bin * cond + (1 + cond | pnum) + (1 + cond | target), dataret)
summary(retmodeld)

retmodele=lmer(targhit ~ bin * cond + (1 + cond | pnum) + (1 | target), dataret)
summary(retmodele)

retmodelf=lmer(targhit ~ bin * cond + (1 | pnum) + (1 | target), dataret)
summary(retmodelf)#as with the memory reactivation trials, while model e and f converge, their nested models don't, which makes it impossible to test the fixed effects. So, remove random effects until all nested models converge. The eventual random effects structure is the same as the original model.

retmodelfull=retmodelf

retmodel1=lmer(targhit ~ 1 + (1   | pnum) + (1 | target), dataret)
retmodel2=lmer(targhit ~ bin + (1  | pnum) + (1 | target), dataret)
retmodel3=lmer(targhit ~ cond + bin + (1| pnum) + (1 | target), dataret)

anova(retmodel1, retmodel2)# test bin. main effect of bin
anova(retmodel2, retmodel3)# test condition. no main effect of condition
anova(retmodel3, retmodelfull)# test interaction. no interaction
summary(retmodelfull)
